@@ -3,7 +3,7 @@ package fa_code_demo;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright (C) 2000-2014  Brian M. Kelly
+#    Copyright (C) 2000-2015  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -303,7 +303,7 @@ sub menu_demo {
       },
 
       Select => 'Many',
-      Banner => "\n   Choose a /bin Utility :"
+      Banner => "\n   Choose a /bin Utility :\n\n"
    );
 
    my @selections=&Menu(\%Menu_1,$unattended);
